@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2016-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2016-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -14,12 +14,13 @@ class AkregatorConfigurePluginListWidget : public PimCommon::ConfigurePluginsLis
     Q_OBJECT
 public:
     explicit AkregatorConfigurePluginListWidget(QWidget *parent = nullptr);
-    ~AkregatorConfigurePluginListWidget();
+    ~AkregatorConfigurePluginListWidget() override;
 
     void save() override;
     void doLoadFromGlobalSettings() override;
     void doResetToDefaultsOther() override;
     void initialize() override;
+
 private:
     void slotConfigureClicked(const QString &configureGroupName, const QString &identifier);
     QVector<PluginItem *> mPluginWebEngineItems;
