@@ -12,9 +12,11 @@
 #include "akregatorinterfaces_export.h"
 
 class QString;
-class QStringList;
-namespace Akregator {
-namespace Backend {
+#include <QStringList>
+namespace Akregator
+{
+namespace Backend
+{
 class Storage;
 
 class AKREGATORINTERFACES_EXPORT StorageFactory
