@@ -11,7 +11,7 @@
 
 #include "storagefactory.h"
 #include <QString>
-class QStringList;
+#include <QStringList>
 
 namespace Akregator {
 namespace Backend {
