@@ -13,10 +13,12 @@
 #include "storagefactory.h"
 #include <QString>
 
-class QStringList;
+#include <QStringList>
 
-namespace Akregator {
-namespace Backend {
+namespace Akregator
+{
+namespace Backend
+{
 class Storage;
 
 class AKREGATORPART_EXPORT StorageFactoryDummyImpl : public StorageFactory
