@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -7,9 +7,11 @@
 #ifndef GRANTLEEUTIL_H
 #define GRANTLEEUTIL_H
 #include <QString>
-namespace Akregator {
+namespace Akregator
+{
 class Feed;
-namespace GrantleeUtil {
+namespace GrantleeUtil
+{
 Q_REQUIRED_RESULT QString imageFeed(const Feed *feed);
 }
 }
