@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2019-2020 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2019-2021 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -25,7 +25,7 @@ bool DownloadFeedIconJob::start()
         return false;
     }
 
-    auto *job = new KIO::FavIconRequestJob(mFeedIconUrl);
+    auto job = new KIO::FavIconRequestJob(mFeedIconUrl);
     if (!mDownloadFavicon) {
         job->setIconUrl(mFeedIconUrl);
     }
