@@ -9,9 +9,11 @@
 #ifndef AKREGATOR_SHARED_H
 #define AKREGATOR_SHARED_H
 
-namespace Akregator {
+namespace Akregator
+{
 struct Shared {
-    Shared() : count(1)
+    Shared()
+        : count(1)
     {
     }
 
