@@ -12,7 +12,8 @@
 #include "akregator_export.h"
 
 #include <KStatusNotifierItem>
-namespace Akregator {
+namespace Akregator
+{
 class AKREGATOR_EXPORT TrayIcon : public KStatusNotifierItem
 {
     Q_OBJECT
@@ -20,6 +21,9 @@ public:
     static TrayIcon *getInstance();
     static void setInstance(TrayIcon *trayIcon);
 
+    bool isEnabled() const;
+    void setEnabled(bool enabled);
+
     explicit TrayIcon(QObject *parent = nullptr);
     ~TrayIcon();
 
@@ -30,6 +34,7 @@ public Q_SLOTS:
 private:
     static TrayIcon *m_instance;
     int m_unread = 0;
+    bool mEnabled = false;
 };
 } // namespace Akregator
 
